@@ -13,6 +13,8 @@ macro_rules! op_onnx {
 
 mod array;
 mod cast;
+mod cumsum;
+mod d2s;
 mod logic;
 mod math;
 mod ml;
@@ -20,6 +22,7 @@ mod nn;
 mod quant;
 pub mod rec;
 mod resize;
+mod s2d;
 
 pub fn register_all_ops(reg: &mut OnnxOpRegister) {
     reg.insert("Cast", cast::cast);
@@ -27,12 +30,15 @@ pub fn register_all_ops(reg: &mut OnnxOpRegister) {
     reg.insert("Identity", |_, _| Ok((Box::new(ops::identity::Identity::default()), vec![])));
     reg.insert("Resize", resize::resize);
     array::register_all_ops(reg);
+    cumsum::register_all_ops(reg);
+    d2s::register_all_ops(reg);
     logic::register_all_ops(reg);
     math::register_all_ops(reg);
     ml::register_all_ops(reg);
     nn::register_all_ops(reg);
     quant::register_all_ops(reg);
     rec::register_all_ops(reg);
+    s2d::register_all_ops(reg);
 }
 
 fn konst(
